from Screens.Screen import Screen
from Components.Sources.StaticText import StaticText
from Tools.Directories import *
import os
from Components.Label import Label
from Components.Pixmap import Pixmap
#from Components.Button import Button
from Components.ActionMap import ActionMap
from enigma import getDesktop
from os import environ as os_environ
import gettext
from Components.Language import language

def localeInit():
    lang = language.getLanguage()[:2]
    os_environ["LANGUAGE"] = lang
    print "[GP2FlashBackup] found LANGUAGE=", lang
    gettext.bindtextdomain("GP2FlashBackup", resolveFilename(SCOPE_PLUGINS, "Extensions/GP2FlashBackup/locale"))

def _(txt):
    t = gettext.dgettext("GP2FlashBackup", txt)
    if t == txt:
        print "[GP2FlashBackup] fallback to default translation for", txt
        t = gettext.gettext(txt)
    return t

localeInit()
language.addCallback(localeInit)

class GP2FlashBackupAbout(Screen):
    try:
        sz_w = getDesktop(0).size().width()
    except:
        sz_w = 720
    if sz_w == 1280:
        skin = """
        <screen name="GP2FlashBackupAbout" position="center,center" title="About GP2 FlashBackup" size="1280,720" flags="wfNoBorder">
        <widget source="Title" render="Label" position="80,80" size="750,30" zPosition="3" font="Regular;26" transparent="1"/>
        <widget source="session.VideoPicture" render="Pig"  position="80,120" size="380,215" zPosition="3" backgroundColor="#ff000000"/>
        <widget source="version" render="Label" position="550,150" size="700,50" font="Regular;22" transparent="1" zPosition="1" halign="left" valign="center" />
        <widget source="author" render="Label" position="600,210" size="700,50" font="Regular;22" transparent="1" zPosition="1" halign="left" valign="center" />
        <widget source="author binarys" render="Label" position="80,350" size="660,50" font="Regular;22" transparent="1" zPosition="1" halign="left" valign="center" />
        <widget source="author script" render="Label" position="230,410" size="660,50" font="Regular;22" transparent="1" zPosition="1" halign="left" valign="center" />
        <widget source="translation" render="Label" position="420,470" size="660,50" font="Regular;22" transparent="1" zPosition="1" halign="left" valign="center" />
        <ePixmap position="1000,500" size="200,92" pixmap="%s" transparent="1" alphatest="blend" />
        <widget name="red" position="80,600" zPosition="1" size="15,16" pixmap="skin_default/buttons/button_red.png" transparent="1" alphatest="on" />
        <widget source="key_red" render="Label" position="100,596" zPosition="2" size="140,25" halign="left" font="Regular;22" transparent="1" />
        </screen>""" % ( resolveFilename(SCOPE_PLUGINS, "Extensions/GP2FlashBackup/gp2.png" ))
    elif sz_w == 1024:
        skin = """
        <screen name="GP2FlashBackupAbout" position="center,center" title="About GP2 FlashBackup" size="1024,576" flags="wfNoBorder">
        <widget source="Title" render="Label" position="80,80" size="750,30" zPosition="3" font="Regular;26" transparent="1"/>
        <widget source="session.VideoPicture" render="Pig"  position="80,120" size="380,215" zPosition="3" backgroundColor="#ff000000"/>
        <widget source="version" render="Label" position="550,150" size="700,50" font="Regular;22" transparent="1" zPosition="1" halign="left" valign="center" />
        <widget source="author" render="Label" position="600,210" size="700,50" font="Regular;22" transparent="1" zPosition="1" halign="left" valign="center" />
        <widget source="author binarys" render="Label" position="80,340" size="660,50" font="Regular;22" transparent="1" zPosition="1" halign="left" valign="center" />
        <widget source="author script" render="Label" position="230,390" size="660,50" font="Regular;22" transparent="1" zPosition="1" halign="left" valign="center" />
        <widget source="translation" render="Label" position="420,440" size="660,50" font="Regular;22" transparent="1" zPosition="1" halign="left" valign="center" />
        <ePixmap position="744,400" size="200,92" pixmap="%s" transparent="1" alphatest="blend" />
        <widget name="red" position="80,500" zPosition="1" size="15,16" pixmap="skin_default/buttons/button_red.png" transparent="1" alphatest="on" />
        <widget source="key_red" render="Label" position="100,496" zPosition="2" size="140,25" halign="left" font="Regular;22" transparent="1" />
        </screen>""" % ( resolveFilename(SCOPE_PLUGINS, "Extensions/GP2FlashBackup/gp2.png" ))
    else:
        skin = """
        <screen name="GP2FlashBackupAbout" position="center,center" title="About GP2 FlashBackup" size="540,460" >
        <ePixmap position="300,40" size="200,92" pixmap="%s" transparent="1" alphatest="blend" />
        <ePixmap pixmap="skin_default/buttons/red.png" zPosition="1" position="0,0" size="140,40" alphatest="on" />
        <widget source="key_red" render="Label" position="0,0" zPosition="2" size="135,40" halign="center" valign="center" font="Regular;22" transparent="1" shadowColor="black" shadowOffset="-1,-1" /> 
        <widget source="version" render="Label" position="10,70" size="700,50" font="Regular;22" transparent="1" zPosition="1" halign="left" valign="center" />
        <widget source="author" render="Label" position="40,130" size="700,50" font="Regular;22" transparent="1" zPosition="1" halign="left" valign="center" />
        <widget source="author binarys" render="Label" position="70,200" size="660,50" font="Regular;22" transparent="1" zPosition="1" halign="left" valign="center" />
        <widget source="author script" render="Label" position="100,260" size="660,50" font="Regular;22" transparent="1" zPosition="1" halign="left" valign="center" />
        <widget source="translation" render="Label" position="130,320" size="660,50" font="Regular;22" transparent="1" zPosition="1" halign="left" valign="center" />
        </screen>""" % ( resolveFilename(SCOPE_PLUGINS, "Extensions/GP2FlashBackup/gp2.png" ))

    def __init__(self, session):
        Screen.__init__(self, session)
        self["aboutActions"] = ActionMap(["ShortcutActions", "WizardActions", "InfobarEPGActions"],
        {
            "red": self.exit,
            "back": self.exit,
            "ok": self.exit,
        }, -1)
        self["version"] = StaticText(_("Version:\n") + '  1.4.7')
        self["author"] = StaticText(_("Developer:\n  JackDaniel"))
        self["author binarys"] = StaticText(_("Thanks at the developer of the Binarys:\n  mechatron"))
        self["author script"] = StaticText(_("Thanks at the developer of the Scripts:\n  Erim"))
        self["translation"] = StaticText(_("Thanks for translation to:\n") + '  NL=ni_hao,PL=kosmacz')
        self["key_red"] = StaticText(_("Close"))
        self["red"] = Pixmap()
        self.onLayoutFinish.append(self.setWindowTitle)

    def setWindowTitle(self):
        self.setTitle(_("About GP2 FlashBackup"))

    def exit(self):
        self.close()