from Plugins.Plugin import PluginDescriptor
from Screens.Console import Console
from Screens.ChoiceBox import ChoiceBox
from Screens.MessageBox import MessageBox
from Screens.Screen import Screen
from Components.ActionMap import ActionMap, NumberActionMap
from Components.Input import Input
from Components.Sources.StaticText import StaticText
from Components.ScrollLabel import ScrollLabel
from Components.Pixmap import Pixmap
from Components.Button import Button
from Components.Label import Label
from Components.MenuList import MenuList
from Components.Sources.List import List
from Components.Slider import Slider
from Components.Harddisk import harddiskmanager
from Components.config import getConfigListEntry, ConfigSubsection, ConfigText, ConfigLocations, ConfigSelection, ConfigBoolean
from Components.config import config
from Components.ConfigList import ConfigListScreen
from Components.Console import Console
from Components.MultiContent import MultiContentEntryText, MultiContentEntryPixmapAlphaTest
from Components.SelectionList import SelectionList
from Components.PluginComponent import plugins
from Components.Language import language
from Components.AVSwitch import AVSwitch
from Tools.Directories import pathExists, fileExists, resolveFilename, SCOPE_PLUGINS, SCOPE_CURRENT_PLUGIN, SCOPE_CURRENT_SKIN, SCOPE_METADIR, SCOPE_MEDIA
from Tools.LoadPixmap import LoadPixmap
from enigma import eTimer, quitMainloop, RT_HALIGN_LEFT, RT_VALIGN_CENTER, eListboxPythonMultiContent, eListbox, gFont, getDesktop
from cPickle import dump, load
from os import path as os_path, system as os_system, unlink, stat, mkdir, popen, makedirs, listdir, access, rename, remove, W_OK, R_OK, F_OK
from time import time, gmtime, strftime, localtime
from stat import ST_MTIME
from datetime import date
from os import environ as os_environ
import gettext
import os
from About import GP2FlashBackupAbout
from BackupLocation import BackupLocation
from BackupStart import makeGP2FlashBackup, getBackupPath
from BackupStartopenTelnet import makeGP2FlashBackupTelnet

config.plugins.GP2FlashBackup = ConfigSubsection()
config.plugins.GP2FlashBackup.backuplocation = ConfigText(default = '/media/hdd/', visible_width = 50, fixed_size = False)
config.plugins.GP2FlashBackup.log = ConfigText(default = '2> /tmp/FlashBackupLog >&1')
config.plugins.GP2FlashBackup.debug = ConfigText(default = "debugon")
config.plugins.GP2FlashBackup.swap = ConfigSelection([("auto", "auto"),("128", "128 MB"),("256", "256 MB"),("512", "512 MB")], default = "auto")
config.plugins.GP2FlashBackup.swapsize = ConfigText(default = '0')
config.plugins.GP2FlashBackup.disclaimer = ConfigBoolean(default = False)

def localeInit():
    lang = language.getLanguage()[:2]
    os_environ["LANGUAGE"] = lang
    print "[GP2FlashBackup] found LANGUAGE=", lang
    gettext.bindtextdomain("GP2FlashBackup", resolveFilename(SCOPE_PLUGINS, "Extensions/GP2FlashBackup/locale"))

def _(txt):
    t = gettext.dgettext("GP2FlashBackup", txt)
    if t == txt:
        print "[GP2FlashBackup] fallback to default translation for", txt
        t = gettext.gettext(txt)
    return t

localeInit()
language.addCallback(localeInit)

def write_cache(cache_file, cache_data):
    if not os_path.isdir( os_path.dirname(cache_file) ):
        try:
            mkdir( os_path.dirname(cache_file) )
        except OSError:
                print os_path.dirname(cache_file), 'is a file'
    fd = open(cache_file, 'w')
    dump(cache_data, fd, -1)
    fd.close()

def valid_cache(cache_file, cache_ttl):
    try:
        mtime = stat(cache_file)[ST_MTIME]
    except:
        return 0
    curr_time = time()
    if (curr_time - mtime) > cache_ttl:
        return 0
    else:
        return 1

def load_cache(cache_file):
    fd = open(cache_file)
    cache_data = load(fd)
    fd.close()
    return cache_data

class GP2FlashBackupDisclaimer(Screen):
    try:
        sz_w = getDesktop(0).size().width()
    except:
        sz_w = 720
    if sz_w == 1280:
        skin = """
        <screen name="GP2FlashBackupDisclaimer" position="center,center" size="1280,720" title=" " flags="wfNoBorder">
            <widget source="Title" render="Label" position="80,80" size="450,30" zPosition="3" font="Regular;22" transparent="1"/>
            <widget source="session.VideoPicture" render="Pig"  position="80,120" size="380,215" zPosition="3" backgroundColor="#ff000000"/>
            <widget source="disclaimertext" render="Label" position="550,150" zPosition="1" size="610,400" font="Regular;26" transparent="1" />
            <widget name="red"   pixmap="skin_default/buttons/button_red.png"   position="80,500" size="15,16" alphatest="on" />
            <widget name="green" pixmap="skin_default/buttons/button_green.png" position="80,550" size="15,16" alphatest="on" />
            <widget source="key_red"   render="Label" position="110,496" zPosition="1" size="300,25" font="Regular;22" halign="left" transparent="1" />
            <widget source="key_green" render="Label" position="110,546" zPosition="1" size="300,25" font="Regular;22" halign="left" transparent="1" />
        </screen>"""
    elif sz_w == 1024:
        skin = """
        <screen name="GP2FlashBackupDisclaimer" position="center,center" size="1024,576" title=" " flags="wfNoBorder">
            <widget source="Title" render="Label" position="80,80" size="450,30" zPosition="3" font="Regular;22" transparent="1"/>
            <widget source="session.VideoPicture" render="Pig"  position="80,120" size="380,215" zPosition="3" backgroundColor="#ff000000"/>
            <widget source="disclaimertext" render="Label" position="500,120" size="444,376" zPosition="1" font="Regular;26" transparent="1" />
            <widget name="red"   pixmap="skin_default/buttons/button_red.png"   position="80,500"  size="15,16" alphatest="on" />
            <widget name="green" pixmap="skin_default/buttons/button_green.png" position="390,500" size="15,16" alphatest="on" />
            <widget source="key_red"   render="Label" position="100,496" zPosition="1" size="200,25" font="Regular;22" halign="left" transparent="1" />
            <widget source="key_green" render="Label" position="410,496" zPosition="1" size="200,25" font="Regular;22" halign="left" transparent="1" />
        </screen>"""
    else:
        skin = """
        <screen name="GP2FlashBackupDisclaimer" position="center,center" size="610,410" title="GP2 FlashBackup Disclaimer">
            <widget source="disclaimertext" render="Label" position="5,70" zPosition="1" size="600,330" font="Regular;26" transparent="1" />
            <widget name="red" position="0,5" zPosition="1" size="135,40" pixmap="skin_default/buttons/red.png" transparent="1" alphatest="on" />
            <widget source="key_red" render="Label" position="0,5" zPosition="2" size="135,40" halign="center" valign="center" font="Regular;16" transparent="1" shadowColor="black" shadowOffset="-1,-1" />   
            <widget name="green" position="135,5" zPosition="1" size="135,40" pixmap="skin_default/buttons/green.png" transparent="1" alphatest="on" />
            <widget source="key_green" render="Label" position="135,5" zPosition="2" size="135,40" halign="center" valign="center" font="Regular;22" transparent="1" shadowColor="black" shadowOffset="-1,-1" />
        </screen>"""

    def __init__(self, session, args = 0):
        Screen.__init__(self, session)
        self["disclaimertext"] = StaticText(_("To create FlashBackups on their own risk!!!\nTo create backups can be dangerous,as well as to flash this.\nIn IhaD Board, there is no support for backup images, and the spread of such backups in the board is prohibited."))
        self["red"] = Pixmap()
        self["green"] = Pixmap()
        self["key_red"] = StaticText(_("I do not agree"))
        self["key_green"] = StaticText(_("I agree"))
        self["setupActions"] = ActionMap([ "ColorActions", "SetupActions" ],
        {
            "red": self.cancel,
            "green": self.gotoplugin,
        })
        self.onShown.append(self.setWindowTitle)

    def setWindowTitle(self):
        self.setTitle(_("GP2 FlashBackup Disclaimer"))

    def gotoplugin(self):
        if config.plugins.GP2FlashBackup.disclaimer.value == False:
            config.plugins.GP2FlashBackup.disclaimer.setValue(True)
            config.plugins.GP2FlashBackup.disclaimer.save()
            self.session.openWithCallback(self.closeme, GP2FlashBackup)
        else:
            self.close(None)
    
    def closeme(self, result):
        self.close(None)

    def cancel(self):
        config.plugins.GP2FlashBackup.disclaimer.setValue(False)
        config.plugins.GP2FlashBackup.disclaimer.save()
        self.close(None)

class GP2FlashBackup(Screen):
    try:
        sz_w = getDesktop(0).size().width()
    except:
        sz_w = 720
    if sz_w == 1280:
        skin = """
        <screen name="GP2FlashBackup" position="center,center" size="1280,720" title="GP2 FlashBackup" flags="wfNoBorder">
            <widget source="Title" render="Label" position="80,80" size="350,30" zPosition="3" font="Regular;26" transparent="1"/>
            <widget source="text" render="Label" position="80,470" size="260,25" font="Regular;22" transparent="1" zPosition="1" foregroundColor="#ffffff" />
            <widget name="target" position="80,500" size="540,22" valign="left" font="Regular;22" transparent="1" />
            <ePixmap pixmap="skin_default/buttons/button_red.png" position="80,600" size="15,16" alphatest="on" />
            <widget source="key_red" render="Label" position="100,596" zPosition="1" size="140,25" font="Regular;22" halign="left" transparent="1" />
        <widget source="session.VideoPicture" render="Pig"  position="80,120" size="380,215" zPosition="3" backgroundColor="#ff000000"/>
        <widget source="menu" render="Listbox" position="550,120" size="610,200" zPosition="3" scrollbarMode="showNever">
                <convert type="TemplatedMultiContent">
                    {"template": [
                            MultiContentEntryText(pos = (10, 10), size = (608, 30), flags = RT_HALIGN_LEFT, text = 1), # index 0 is the MenuText,
                        ],
                    "fonts": [gFont("Regular", 26)],
                    "itemHeight": 50
                    }
            </convert>
        </widget>
        <widget source="menu" render="Listbox"     position="80,350" size="1070,250" zPosition="3" scrollbarMode="showNever" selectionDisabled="1" transparent="1">
            <convert type="TemplatedMultiContent">
                {"template": [
                        MultiContentEntryText(pos = (0, 0), size = (1070, 250), flags = RT_HALIGN_CENTER|RT_VALIGN_TOP|RT_WRAP, text = 2), # index 0 is the MenuText,
                    ],
                "fonts": [gFont("Regular", 19)],
                "itemHeight": 250
                }
            </convert>
        </widget>
        </screen>"""        
    elif sz_w == 1024:
        skin = """
        <screen name="GP2FlashBackup" position="center,center" size="1024,576" title="GP2 FlashBackup" flags="wfNoBorder">
            <widget source="Title" render="Label" position="80,80" size="350,30" zPosition="3" font="Regular;26" transparent="1"/>
            <widget source="text" render="Label" position="80,400" size="260,25" font="Regular;20" transparent="1" zPosition="1" foregroundColor="#ffffff" />
            <widget name="target" position="80,430" size="540,22" valign="left" font="Regular;20" transparent="1" />
            <ePixmap pixmap="skin_default/buttons/button_red.png" position="80,500" size="15,16" alphatest="on" />
            <widget source="key_red" render="Label" position="100,496" zPosition="1" size="140,25" font="Regular;22" halign="left" transparent="1" />
            <widget source="session.VideoPicture" render="Pig"  position="80,120" size="380,215" zPosition="3" backgroundColor="#ff000000"/>
            <widget source="menu" render="Listbox" position="500,120" size="444,200" zPosition="3" scrollbarMode="showNever">
                <convert type="TemplatedMultiContent">
                    {"template": [
                            MultiContentEntryText(pos = (10, 10), size = (434, 30), flags = RT_HALIGN_LEFT, text = 1), # index 0 is the MenuText,
                        ],
                    "fonts": [gFont("Regular", 26)],
                    "itemHeight": 50
                    }
            </convert>
        </widget>
        <widget source="menu" render="Listbox"     position="500,320" size="444,250" zPosition="3" scrollbarMode="showNever" selectionDisabled="1" transparent="1">
            <convert type="TemplatedMultiContent">
                {"template": [
                        MultiContentEntryText(pos = (0, 0), size = (444, 250), flags = RT_HALIGN_CENTER|RT_VALIGN_TOP|RT_WRAP, text = 2), # index 0 is the MenuText,
                    ],
                "fonts": [gFont("Regular", 18)],
                "itemHeight": 250
                }
            </convert>
        </widget>
        </screen>"""   
    else:
        skin = """        
        <screen name="GP2FlashBackup" position="center,center" size="610,410" title="GP2 FlashBackup" >
            <widget source="text" render="Label" position="15,350" size="540,25" font="Regular;22" transparent="1" zPosition="1" foregroundColor="#ffffff" />
            <widget name="target" position="15,370" size="580,50" valign="left" font="Regular;22" />
            <ePixmap pixmap="skin_default/buttons/red.png" zPosition="1" position="0,0" size="140,40" alphatest="on" />
            <widget source="key_red" render="Label" position="0,0" zPosition="2" size="135,40" halign="center" valign="center" font="Regular;22" transparent="1" shadowColor="black" shadowOffset="-1,-1" /> 
            <ePixmap pixmap="skin_default/border_menu_350.png" position="5,50" zPosition="1" size="350,300" transparent="1" alphatest="on" />
            <widget source="menu" render="Listbox" position="15,60" size="330,290" scrollbarMode="showOnDemand">
                <convert type="TemplatedMultiContent">
                    {"template": [
                            MultiContentEntryText(pos = (2, 2), size = (330, 24), flags = RT_HALIGN_LEFT, text = 1), # index 0 is the MenuText,
                        ],
                    "fonts": [gFont("Regular", 22)],
                    "itemHeight": 25
                    }
                </convert>
            </widget>
            <widget source="menu" render="Listbox" position="360,10" size="240,390" scrollbarMode="showNever" selectionDisabled="1">
                <convert type="TemplatedMultiContent">
                    {"template": [
                            MultiContentEntryText(pos = (2, 2), size = (240, 390), flags = RT_HALIGN_CENTER|RT_VALIGN_CENTER|RT_WRAP, text = 2), # index 2 is the Description,
                        ],
                    "fonts": [gFont("Regular", 22)],
                    "itemHeight": 390
                    }
                </convert>
            </widget>
        </screen>"""

    def __init__(self, session, args = 0):
        Screen.__init__(self, session)
        self.skin_path = plugin_path      
        self.menu = args
        self.list = []
        self.oktext = _("\nPress OK on your remote control to continue.")
        self.text = ""
        if self.menu == 0:
            self.list.append(("backup", _("Start Backup"), _("\nStarts backup from yours Flash-Image." ) + self.oktext, None))
            self.list.append(("backuplocation", _("Choose backup location"),  _("\nSelect your backup device." ) + self.oktext, None))
            if config.usage.setup_level.index >= 2: # expert+
                self.list.append(("advanced", _("Advanced Options"), _("\nAdvanced options and settings." ) + self.oktext, None))
        elif self.menu == 1:
            self.list.append(("backuptelnetopen", _("Start Backup (for Debug)"), _("\nStarts backup from yours Flash-Image, after finish Telnet will be open for Debug info.\nATTENTION: A FlashBackupLog will be creat in /tmp, by problems please post this Log (as a file attachment).\nWith EXIT or OK key the console becomes closed.") + self.oktext, None))
            self.list.append(("swap", _("Setup Swapsize"),  _("\nSelect your Swapsize.\nCurrent Swapsize: " ) + config.plugins.GP2FlashBackup.swap.value + ' MB' + self.oktext, None))
            self.list.append(("disclaimer", _("Disclaimer"),  _("\nDisclaimer from the GP2 FlashBackup Plugin." ) + self.oktext, None))
            self.list.append(("about", _("About..."),  _("\nAbout GP2 FlashBackup Plugin." ) + self.oktext, None))
            
        
        self["menu"] = List(self.list)
        self["key_red"] = StaticText(_("Cancel"))
        self["status"] = StaticText("")
        self["text"] = StaticText(_("Selected memory place:"))
        self["target"] = Label(config.plugins.GP2FlashBackup.backuplocation.value)

        self["shortcuts"] = ActionMap(["ShortcutActions", "WizardActions", "InfobarEPGActions"],
        {
            "ok": self.go,
            "back": self.cancel,
            "red": self.cancel,
        }, -1)
        self.onLayoutFinish.append(self.layoutFinished)
        self.onShown.append(self.setWindowTitle)

    def layoutFinished(self):
        idx = 0
        self["menu"].index = idx


    def setWindowTitle(self):
        self.setTitle(_("GP2 FlashBackup"))

    def go(self):
        current = self["menu"].getCurrent()
        if current:
            currentEntry = current[0]
        if self.menu == 0:
            if (currentEntry == "backup"):
                    if config.plugins.GP2FlashBackup.disclaimer.value == False:
                        self.session.open(MessageBox, _("Sorry, Disclaimer not accepted !!!"), MessageBox.TYPE_INFO)
                    else:
                        self.session.openWithCallback(self.backupDone, makeGP2FlashBackup, runBackup = True)
            elif (currentEntry == "backuplocation"): 
                    if config.plugins.GP2FlashBackup.disclaimer.value == False:
                        self.session.open(MessageBox, _("Sorry, Disclaimer not accepted !!!"), MessageBox.TYPE_INFO)
                    else:
                        self.session.openWithCallback(self.backuplocation_choosen, BackupLocation)
            elif (currentEntry == "advanced"):
                    self.session.open(GP2FlashBackup, 1)
        elif self.menu == 1:
            if (currentEntry == "backuptelnetopen"): 
                    if config.plugins.GP2FlashBackup.disclaimer.value == False:
                        self.session.open(MessageBox, _("Sorry, Disclaimer not accepted !!!"), MessageBox.TYPE_INFO)
                    else:
                        self.session.open(makeGP2FlashBackupTelnet, runBackup = True)
            elif (currentEntry == "swap"):
                    if config.plugins.GP2FlashBackup.disclaimer.value == False:
                        self.session.open(MessageBox, _("Sorry, Disclaimer not accepted !!!"), MessageBox.TYPE_INFO)
                    else:
                        self.session.open(swap)
            elif (currentEntry == "disclaimer"):
                    self.session.open(GP2FlashBackupDisclaimer)
            elif (currentEntry == "about"):
                    self.session.open(GP2FlashBackupAbout)

    def backuplocation_choosen(self, option):
        self.updateTarget()
        if option is not None:
            config.plugins.GP2FlashBackup.backuplocation.value = str(option[1])
        config.plugins.GP2FlashBackup.backuplocation.save()
        config.plugins.GP2FlashBackup.save()
        config.save()
        self.createBackupfolders()

    def createBackupfolders(self):
        self.backuppath = getBackupPath()
        try:
            if (os_path.exists(self.backuppath) == False):
                makedirs(self.backuppath)
        except OSError:
            self.session.openWithCallback(BackupLocation, MessageBox, _("Sorry, your backup destination is not writeable.\n\nPlease choose another one."), MessageBox.TYPE_ERROR )

    def updateTarget(self):
#        currFolder = (''.join((config.plugins.GP2FlashBackup.backuplocation.value)))
#        if currFolder is not None:
        self["target"].setText(''.join((config.plugins.GP2FlashBackup.backuplocation.value)))

    def backupDone(self,retval = None):
        if retval is True:
            self.cancel()
        else:
            if retval is False:
                self.session.open(MessageBox, _("GP2 FlashBackup failed."), MessageBox.TYPE_ERROR, timeout = 10 )

    def cancel(self):
        self.close(None)

class swap(Screen, ConfigListScreen):
    try:
        sz_w = getDesktop(0).size().width()
    except:
        sz_w = 720
    if sz_w == 1280:
        skin = """
        <screen name="swap" position="center,center" size="1280,720" title="GP2 FlashBackup Swap setting" flags="wfNoBorder">
            <widget source="Title" render="Label" position="80,80" size="550,30" zPosition="3" font="Regular;26" transparent="1"/>
            <widget source="session.VideoPicture" render="Pig"  position="80,120" size="380,215" zPosition="3" backgroundColor="#ff000000"/>
            <widget name="config" position="550,150" size="610,150" zPosition="3" scrollbarMode="showOnDemand" transparent="1" />
            <widget name="red" pixmap="skin_default/buttons/button_red.png" position="80,600" size="15,16" alphatest="on" />
            <widget name="green" pixmap="skin_default/buttons/button_green.png" position="290,600" size="15,16" alphatest="on" />
            <widget source="key_red" render="Label" position="100,596" zPosition="1" size="140,25" font="Regular;22" halign="left" transparent="1" />
            <widget source="key_green" render="Label" position="310,596" zPosition="1" size="140,25" font="Regular;22" halign="left" transparent="1" />
        </screen>"""

    elif sz_w == 1024:
        skin = """
        <screen name="swap" position="center,center" size="1024,576" title="GP2 FlashBackup Swap setting" flags="wfNoBorder">
            <widget source="Title" render="Label" position="80,80" size="550,30" zPosition="3" font="Regular;26" transparent="1"/>
            <widget source="session.VideoPicture" render="Pig"  position="80,120" size="380,215" zPosition="3" backgroundColor="#ff000000"/>
            <widget name="config" position="550,150" size="394,150" zPosition="3" scrollbarMode="showOnDemand" transparent="1" />
            <widget name="red" pixmap="skin_default/buttons/button_red.png" position="80,500" size="15,16" alphatest="on" />
            <widget name="green" pixmap="skin_default/buttons/button_green.png" position="290,500" size="15,16" alphatest="on" />
            <widget source="key_red" render="Label" position="100,496" zPosition="1" size="140,25" font="Regular;22" halign="left" transparent="1" />
            <widget source="key_green" render="Label" position="310,496" zPosition="1" size="140,25" font="Regular;22" halign="left" transparent="1" />
        </screen>"""
        
    else:
        skin = """         
        <screen position="center,center" size="400,100" title="GP2 FlashBackup Swap setting" >
            <widget name="config" position="5,70" size="390,50" scrollbarMode="showOnDemand" />
            <widget name="red" position="0,5" zPosition="1" size="135,40" pixmap="skin_default/buttons/red.png" transparent="1" alphatest="on" />
            <widget source="key_red" render="Label" position="0,5" zPosition="2" size="135,40" halign="center" valign="center" font="Regular;22" transparent="1" shadowColor="black" shadowOffset="-1,-1" />   
            <widget name="green" position="135,5" zPosition="1" size="135,40" pixmap="skin_default/buttons/green.png" transparent="1" alphatest="on" />
            <widget source="key_green" render="Label" position="135,5" zPosition="2" size="135,40" halign="center" valign="center" font="Regular;22" transparent="1" shadowColor="black" shadowOffset="-1,-1" />
        </screen>"""
    
    def __init__(self, session, args = 0):
        self.session = session
        Screen.__init__(self, session)
        
        self.list = []
        self.list.append(getConfigListEntry(_("Swapsize: "), config.plugins.GP2FlashBackup.swap))
        ConfigListScreen.__init__(self, self.list)
        self["green"] = Pixmap()
        self["red"] = Pixmap()
        self["key_red"] = StaticText(_("Cancel"))
        self["key_green"] = StaticText(_("Save"))
        self["shortcuts"] = ActionMap(["ShortcutActions", "WizardActions", "InfobarEPGActions"],
        {
            "ok": self.save,
            "back": self.cancel,
            "green": self.save,
            "red": self.cancel,
        }, -1)
        self.onShown.append(self.setWindowTitle)

    def setWindowTitle(self):
        self.setTitle(_("GP2 FlashBackup Swap setting"))

    def save(self):
        for x in self["config"].list:
            x[1].save()
        self.close(None)

    def cancel(self):
        self.close(None)

def main(session,**kwargs):
    if config.plugins.GP2FlashBackup.disclaimer.value == False:
        session.open(GP2FlashBackupDisclaimer)
    else:
        session.open(GP2FlashBackup)

def startSetup(menuid):
    if menuid != "setup": 
        return [ ]
    return [(_("GP2 FlashBackup"), main, "GP2FlashBackup", 50)]

def Plugins(path, **kwargs):
    global plugin_path
    plugin_path = path
    list = [
            PluginDescriptor(name=_("GP2 FlashBackup"), description =_("1:1 Flashimage-Backup on HDD, CF, SD, USB or Networkmount"), where = PluginDescriptor.WHERE_PLUGINMENU, icon="gp2flashbackup.png", fnc=main),
            PluginDescriptor(name=_("GP2 FlashBackup"), description =_("1:1 Flashimage-Backup on HDD, CF, SD, USB or Networkmount"), where = PluginDescriptor.WHERE_MENU, fnc=startSetup),
            PluginDescriptor(name=_("GP2 FlashBackup"), description =_("1:1 Flashimage-Backup on HDD, CF, SD, USB or Networkmount"), where = PluginDescriptor.WHERE_EXTENSIONSMENU, fnc=main)
        ]
    return list
